package MouseX::POE::Meta::Method::State;
$MouseX::POE::Meta::Method::State::VERSION = '0.216';
# ABSTRACT: Dont look into this, its boring
use strict;
use Mouse;
extends qw(Mouse::Meta::Method);

no Mouse;
1;

__END__

=pod

=encoding UTF-8

=head1 NAME

MouseX::POE::Meta::Method::State - Dont look into this, its boring

=head1 VERSION

version 0.216

=head1 AUTHORS

=over 4

=item *

Chris Prather <chris@prather.org>

=item *

Ash Berlin <ash@cpan.org>

=item *

Chris Williams <chris@bingosnet.co.uk>

=item *

Yuval (nothingmuch) Kogman

=item *

Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Chris Prather, Ash Berlin, Chris Williams, Yuval Kogman, Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
